@@ -87,7 +87,7 @@ static enum mympd_cmd_acl_entity mympd_cmd_acl[] = {
     [MYMPD_API_LAST_PLAYED_LIST] = API_PUBLIC,
     [MYMPD_API_LIKE] = API_PUBLIC | API_MYMPD_ONLY,
     [MYMPD_API_LOGLEVEL] = API_PUBLIC | API_PROTECTED | API_MYMPD_ONLY,
-    [MYMPD_API_LYRICS_GET] = API_PUBLIC,
+    [MYMPD_API_LYRICS_GET] = API_PUBLIC | API_MYMPD_ONLY,
     [MYMPD_API_MOUNT_LIST] = API_PUBLIC,
     [MYMPD_API_MOUNT_MOUNT] = API_PUBLIC | API_PROTECTED,
     [MYMPD_API_MOUNT_NEIGHBOR_LIST] = API_PUBLIC,
