@@ -11,7 +11,7 @@
 #ifndef MYMPD_LAST_PLAYED_H
 #define MYMPD_LAST_PLAYED_H
 
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 bool last_played_file_save(struct t_partition_state *partition_state);
 bool last_played_file_read(struct t_partition_state *partition_state);
