@@ -11,7 +11,7 @@
 #ifndef MYMPD_API_ALBUMS_H
 #define MYMPD_API_ALBUMS_H
 
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 sds mympd_api_album_detail(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state,
         sds buffer, unsigned request_id, sds albumid, const struct t_fields *tagcols);
