@@ -11,7 +11,7 @@
 #ifndef MYMPD_API_SONG_H
 #define MYMPD_API_SONG_H
 
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 sds mympd_api_song_details(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state,
     sds buffer, unsigned request_id, const char *uri);
