@@ -11,8 +11,8 @@
 #ifndef MYMPD_API_STATUS_H
 #define MYMPD_API_STATUS_H
 
+#include "src/lib/config/mympd_state.h"
 #include "src/lib/json/json_rpc.h"
-#include "src/lib/mympd_state.h"
 
 unsigned mympd_api_get_elapsed_seconds(struct mpd_status *status);
 sds mympd_api_status_print(struct t_partition_state *partition_state, struct t_cache *album_cache, sds buffer, struct mpd_status *status);
