@@ -13,7 +13,7 @@
 
 #include "dist/sds/sds.h"
 #include "src/lib/api.h"
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 sds mympd_api_volume_set(struct t_partition_state *partition_state, unsigned volume_min, unsigned volume_max,
         sds buffer, enum mympd_cmd_ids cmd_id, unsigned request_id, unsigned volume);
