@@ -13,12 +13,12 @@
 
 #include "dist/sds/sds.h"
 #include "src/lib/cache/cache_rax_album.h"
+#include "src/lib/config/mympd_state.h"
 #include "src/lib/json/json_print.h"
 #include "src/lib/json/json_rpc.h"
 #include "src/lib/log.h"
 #include "src/lib/mem.h"
 #include "src/lib/msg_queue.h"
-#include "src/lib/mympd_state.h"
 #include "src/lib/sds_extras.h"
 #include "src/lib/timer.h"
 #include "src/mympd_api/trigger.h"
