@@ -12,10 +12,9 @@
 #include "src/webserver/utility.h"
 
 #include "src/lib/cache/cache_disk_images.h"
-#include "src/lib/config_def.h"
+#include "src/lib/config/config_def.h"
 #include "src/lib/filehandler.h"
 #include "src/lib/log.h"
-#include "src/lib/mimetype.h"
 #include "src/lib/sds_extras.h"
 #include "src/lib/utility.h"
 #include "src/webserver/response.h"
