@@ -12,7 +12,7 @@
 #include "src/webserver/webserver.h"
 
 #include "src/lib/api.h"
-#include "src/lib/http_client.h"
+#include "src/lib/http_client/http_client.h"
 #include "src/lib/json/json_rpc.h"
 #include "src/lib/log.h"
 #include "src/lib/mem.h"
@@ -265,6 +265,16 @@ static bool parse_internal_message(struct t_work_response *response, struct t_mg
         mg_user_data->image_names_lg = sds_split_comma_trim(new_mg_user_data->image_names_lg, &mg_user_data->image_names_lg_len);
         FREE_SDS(new_mg_user_data->image_names_lg);
 
+        // Lyrics
+        mg_user_data->lyrics.uslt_ext = sds_replace(mg_user_data->lyrics.uslt_ext, new_mg_user_data->lyrics.uslt_ext);
+        FREE_SDS(new_mg_user_data->lyrics.uslt_ext);
+        mg_user_data->lyrics.sylt_ext = sds_replace(mg_user_data->lyrics.sylt_ext, new_mg_user_data->lyrics.sylt_ext);
+        FREE_SDS(new_mg_user_data->lyrics.sylt_ext);
+        mg_user_data->lyrics.vorbis_uslt = sds_replace(mg_user_data->lyrics.vorbis_uslt, new_mg_user_data->lyrics.vorbis_uslt);
+        FREE_SDS(new_mg_user_data->lyrics.vorbis_uslt);
+        mg_user_data->lyrics.vorbis_sylt = sds_replace(mg_user_data->lyrics.vorbis_sylt, new_mg_user_data->lyrics.vorbis_sylt);
+        FREE_SDS(new_mg_user_data->lyrics.vorbis_sylt);
+
         //set per partition stream uris
         list_clear(&mg_user_data->stream_uris);
         struct t_list_node *current = new_mg_user_data->partitions.head;
@@ -324,6 +334,92 @@ static void handle_wakeup(struct mg_connection *nc, struct mg_str *data) {
     }
 }
 
+/**
+ * Validates the request
+ * @param nc Mongoose conncection
+ * @param hm HTTP Request
+ * @return true on valid request, else false
+ */
+static bool check_request(struct mg_connection *nc, struct mg_http_message *hm) {
+    // First log it
+    if (hm->query.len > 0) {
+        MYMPD_LOG_INFO(NULL, "HTTP request (%lu): %.*s %.*s?%.*s %.*s",
+            nc->id,
+            (int)hm->method.len, hm->method.buf,
+            (int)hm->uri.len, hm->uri.buf,
+            (int)hm->query.len, hm->query.buf,
+            (int)hm->proto.len, hm->proto.buf
+        );
+    }
+    else {
+        MYMPD_LOG_INFO(NULL, "HTTP request (%lu): %.*s %.*s %.*s",
+            nc->id,
+            (int)hm->method.len, hm->method.buf,
+            (int)hm->uri.len, hm->uri.buf,
+            (int)hm->proto.len, hm->proto.buf
+        );
+    }
+    //limit protocol
+    if (mg_strcmp(hm->proto, mg_str("HTTP/1.1")) == 0) {
+        nc->data[2] = 'K';
+    }
+    else if (mg_strcmp(hm->proto, mg_str("HTTP/1.0")) == 0) {
+        nc->data[2] = 'C';
+    }
+    else {
+        MYMPD_LOG_ERROR(NULL, "Invalid http protocol \"%.*s\" (%lu)", (int)hm->proto.len, hm->proto.buf, nc->id);
+        webserver_send_error(nc, 405, "Invalid http protocol");
+        nc->is_draining = 1;
+        return false;
+    }
+    //limit allowed http methods
+    if (mg_strcmp(hm->method, mg_str("GET")) == 0) {
+        nc->data[1] = 'G';
+    }
+    else if (mg_strcmp(hm->method, mg_str("HEAD")) == 0) {
+        nc->data[1] = 'H';
+    }
+    else if (mg_strcmp(hm->method, mg_str("POST")) == 0) {
+        nc->data[1] = 'P';
+    }
+    else if (mg_strcmp(hm->method, mg_str("OPTIONS")) == 0) {
+        nc->data[1] = 'O';
+        webserver_send_cors_reply(nc);
+        return false;
+    }
+    else {
+        MYMPD_LOG_ERROR(NULL, "Invalid http method \"%.*s\" (%lu)", (int)hm->method.len, hm->method.buf, nc->id);
+        webserver_send_error(nc, 405, "Invalid http method");
+        //nc->is_draining = 1;
+        return false;
+    }
+    //check uri length
+    if (hm->uri.len > URI_LENGTH_MAX) {
+        MYMPD_LOG_ERROR(NULL, "Uri is too long, length is %lu, maximum length is %d (%lu)", (unsigned long)hm->uri.len, URI_LENGTH_MAX, nc->id);
+        webserver_send_error(nc, 414, "Uri is too long");
+        //nc->is_draining = 1;
+        return false;
+    }
+    //check post requests length
+    if (nc->data[1] == 'P' && (hm->body.len == 0 || hm->body.len > BODY_SIZE_MAX)) {
+        MYMPD_LOG_ERROR(NULL, "POST request with body of size %lu is out of bounds (%lu)", (unsigned long)hm->body.len, nc->id);
+        webserver_send_error(nc, 413, "Post request is too large");
+        //nc->is_draining = 1;
+        return false;
+    }
+    //respect connection close header
+    struct mg_str *connection_hdr = mg_http_get_header(hm, "Connection");
+    if (connection_hdr != NULL) {
+        if (mg_strcasecmp(*connection_hdr, mg_str("close")) == 0) {
+            nc->data[2] = 'C';
+        }
+        else {
+            nc->data[2] = 'K';
+        }
+    }
+    return true;
+}
+
 /**
  * Central webserver event handler
  * nc->label usage
@@ -361,7 +457,7 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data) {
                 //set labels
                 nc->data[0] = 'F'; // connection type
                 nc->data[1] = '-'; // http method
-                nc->data[2] = 'C'; // connection header
+                nc->data[2] = '-'; // connection header
             }
             break;
         }
@@ -435,58 +531,8 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data) {
         case MG_EV_HTTP_MSG: {
             nc->is_resp = 1;
             struct mg_http_message *hm = (struct mg_http_message *) ev_data;
-            if (hm->query.len > 0) {
-                MYMPD_LOG_INFO(NULL, "HTTP request (%lu): %.*s %.*s?%.*s", nc->id, (int)hm->method.len, hm->method.buf,
-                    (int)hm->uri.len, hm->uri.buf, (int)hm->query.len, hm->query.buf);
-            }
-            else {
-                MYMPD_LOG_INFO(NULL, "HTTP request (%lu): %.*s %.*s", nc->id, (int)hm->method.len, hm->method.buf,
-                    (int)hm->uri.len, hm->uri.buf);
-            }
-            //limit allowed http methods
-            if (mg_strcmp(hm->method, mg_str("GET")) == 0) {
-                nc->data[1] = 'G';
-            }
-            else if (mg_strcmp(hm->method, mg_str("HEAD")) == 0) {
-                nc->data[1] = 'H';
-            }
-            else if (mg_strcmp(hm->method, mg_str("POST")) == 0) {
-                nc->data[1] = 'P';
-            }
-            else if (mg_strcmp(hm->method, mg_str("OPTIONS")) == 0) {
-                nc->data[1] = 'O';
-                webserver_send_cors_reply(nc);
-                return;
-            }
-            else {
-                MYMPD_LOG_ERROR(NULL, "Invalid http method \"%.*s\" (%lu)", (int)hm->method.len, hm->method.buf, nc->id);
-                webserver_send_error(nc, 405, "Invalid http method");
-                nc->is_draining = 1;
-                return;
-            }
-            //check uri length
-            if (hm->uri.len > URI_LENGTH_MAX) {
-                MYMPD_LOG_ERROR(NULL, "Uri is too long, length is %lu, maximum length is %d (%lu)", (unsigned long)hm->uri.len, URI_LENGTH_MAX, nc->id);
-                webserver_send_error(nc, 414, "Uri is too long");
-                nc->is_draining = 1;
-                return;
-            }
-            //check post requests length
-            if (nc->data[1] == 'P' && (hm->body.len == 0 || hm->body.len > BODY_SIZE_MAX)) {
-                MYMPD_LOG_ERROR(NULL, "POST request with body of size %lu is out of bounds (%lu)", (unsigned long)hm->body.len, nc->id);
-                webserver_send_error(nc, 413, "Post request is too large");
-                nc->is_draining = 1;
-                return;
-            }
-            //respect connection close header
-            struct mg_str *connection_hdr = mg_http_get_header(hm, "Connection");
-            if (connection_hdr != NULL) {
-                if (mg_strcasecmp(*connection_hdr, mg_str("close")) == 0) {
-                    nc->data[2] = 'C';
-                }
-                else {
-                    nc->data[2] = 'K';
-                }
+            if (check_request(nc, hm) == false) {
+                break;
             }
             //handle uris
             if (mg_match(hm->uri, mg_str("/api/*"), NULL)) {
@@ -524,22 +570,22 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data) {
                 request_handler_albumart_by_album_id(hm, nc->id, ALBUMART_MD);
             }
             else if (mg_match(hm->uri, mg_str("/albumart-large"), NULL)) {
-                request_handler_albumart_by_uri(nc, hm, mg_user_data, nc->id, ALBUMART_LG);
+                request_handler_albumart_by_uri(nc, hm, ALBUMART_LG);
             }
             else if (mg_match(hm->uri, mg_str("/albumart-thumb"), NULL)) {
-                request_handler_albumart_by_uri(nc, hm, mg_user_data, nc->id, ALBUMART_SM);
+                request_handler_albumart_by_uri(nc, hm, ALBUMART_SM);
             }
             else if (mg_match(hm->uri, mg_str("/albumart"), NULL)) {
-                request_handler_albumart_by_uri(nc, hm, mg_user_data, nc->id, ALBUMART_MD);
+                request_handler_albumart_by_uri(nc, hm, ALBUMART_MD);
             }
             else if (mg_match(hm->uri, mg_str("/folderart"), NULL)) {
-                request_handler_folderart(nc, hm, mg_user_data);
+                request_handler_folderart(nc, hm);
             }
             else if (mg_match(hm->uri, mg_str("/tagart"), NULL)) {
-                request_handler_tagart(nc, hm, mg_user_data);
+                request_handler_tagart(nc, hm);
             }
             else if (mg_match(hm->uri, mg_str("/playlistart"), NULL)) {
-                request_handler_playlistart(nc, hm, mg_user_data);
+                request_handler_playlistart(nc, hm);
             }
             else if (mg_match(hm->uri, mg_str("/browse/#"), NULL)) {
                 request_handler_browse(nc, hm, mg_user_data);
@@ -566,7 +612,7 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data) {
                 struct t_list_node *node = list_get_node(&mg_user_data->stream_uris, frontend_nc_data->partition);
                 if (node == NULL) {
                     webserver_send_error(nc, 404, "Stream uri not configured");
-                    nc->is_draining = 1;
+                    //nc->is_draining = 1;
                     break;
                 }
                 create_backend_connection(nc, frontend_nc_data->backend_nc, node->value_p, forward_backend_to_frontend_stream, true);
@@ -721,6 +767,10 @@ static void ev_handler_redirect(struct mg_connection *nc, int ev, void *ev_data)
                 MYMPD_LOG_DEBUG(NULL, "Redirect listening connection opened");
             }
             mg_user_data->connection_count++;
+            //set labels
+            nc->data[0] = 'F'; // connection type
+            nc->data[1] = '-'; // http method
+            nc->data[2] = '-'; // connection header
             break;
         case MG_EV_ACCEPT:
             //enforce connection limit
@@ -734,6 +784,9 @@ static void ev_handler_redirect(struct mg_connection *nc, int ev, void *ev_data)
             break;
         case MG_EV_HTTP_MSG: {
             struct mg_http_message *hm = (struct mg_http_message *) ev_data;
+            if (check_request(nc, hm) == false) {
+                break;
+            }
             // Serve some directories without ssl
             if (mg_match(hm->uri, mg_str("/webradio"), NULL)) {
                 request_handler_extm3u(nc, hm, mg_user_data);
@@ -749,7 +802,8 @@ static void ev_handler_redirect(struct mg_connection *nc, int ev, void *ev_data)
             struct mg_str *host_hdr = mg_http_get_header(hm, "Host");
             if (host_hdr == NULL) {
                 MYMPD_LOG_ERROR(NULL, "No host header found, closing connection");
-                nc->is_closing = 1;
+                webserver_send_error(nc, 405, "No host header found");
+                //nc->is_closing = 1;
                 break;
             }
 
@@ -762,7 +816,7 @@ static void ev_handler_redirect(struct mg_connection *nc, int ev, void *ev_data)
             }
             MYMPD_LOG_INFO(NULL, "Redirecting to %s", s_redirect);
             webserver_send_header_found(nc, s_redirect, "");
-            nc->is_draining = 1;
+            //nc->is_draining = 1;
             sdsfreesplitres(tokens, count);
             FREE_SDS(host_header);
             FREE_SDS(s_redirect);
